Enum Coefficients
#[non_exhaustive]#[repr(u32)]pub enum Coefficients {
Identity = 1,
Bt709 = 2,
Fcc = 3,
Bt601 = 4,
Smpte240 = 5,
Bt2020 = 6,
Bt2020Cl = 7,
Ictcp = 8,
}wayland and Linux only.Expand description
named coefficients
Named matrix coefficients used to encode well-known sets of coefficients. H.273 is the authority, when it comes to the exact values of coefficients and authoritative specifications, where an equivalent code point exists.
A value of 0 is invalid and will never be present in the list of enums.
Descriptions do list the specifications for convenience.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Identity = 1
The identity matrix
Coefficients as defined by
- IEC 61966-2-1 sRGB
- SMPTE ST 428-1 (2019)
Equivalent to H.273 MatrixCoefficients code point 0. Compatible with pixel formats of the RGB family.
Bt709 = 2
BT.709 matrix coefficients
Coefficients as defined by
- Rec. ITU-R BT.709-6
- Rec. ITU-R BT.1361-0 conventional colour gamut system (historical)
- Rec. ITU-R BT.1361-0 conventional colour gamut system and extended colour gamut system (historical)
- IEC 61966-2-4 xvYCC709
- SMPTE RP 177 (1993) Annex B
Equivalent to H.273 MatrixCoefficients code point 1. Compatible with pixel formats of the YCbCr family.
Fcc = 3
FCC matrix coefficients
Coefficients as defined by
- United States Federal Communications Commission (2003) Title 47 Code of Federal Regulations 73.682 (a) (20)
Equivalent to H.273 MatrixCoefficients code point 4. Compatible with pixel formats of the YCbCr family.
Bt601 = 4
BT.601-7 matrix coefficients
Coefficients as defined by
- Rec. ITU-R BT.470-6 System B, G (historical)
- Rec. ITU-R BT.601-7 625
- Rec. ITU-R BT.601-7 525
- Rec. ITU-R BT.1358-0 625 (historical)
- Rec. ITU-R BT.1358-1 525 or 625 (historical)
- Rec. ITU-R BT.1700-0 625 PAL and 625 SECAM
- Rec. ITU-R BT.1700-0 NTSC
- IEC 61966-2-1 sYCC
- IEC 61966-2-4 xvYCC601
- SMPTE ST 170 (2004)
Equivalent to H.273 MatrixCoefficients code point 5, 6. Compatible with pixel formats of the YCbCr family.
Smpte240 = 5
SMPTE ST 240 matrix coefficients
Coefficients as defined by
- SMPTE ST 240 (1999)
Equivalent to H.273 MatrixCoefficients code point 7. Compatible with pixel formats of the YCbCr family.
Bt2020 = 6
BT.2020 and BT.2100 YCbCr matrix coefficients
Coefficients as defined by
- Rec. ITU-R BT.2020-2 (non-constant luminance)
- Rec. ITU-R BT.2100-2 Y′CbCr
Equivalent to H.273 MatrixCoefficients code point 9. Compatible with pixel formats of the YCbCr family.
Bt2020Cl = 7
BT.2020 matrix coefficients for constant luminance
Coefficients as defined by
- Rec. ITU-R BT.2020-2 (constant luminance)
Equivalent to H.273 MatrixCoefficients code point 10. Compatible with pixel formats of the YCbCr family.
Ictcp = 8
BT.2100 ICtCp matrix coefficients
Coefficients as defined by
- Rec. ITU-R BT.2100-2 ICTCP
Equivalent to H.273 MatrixCoefficients code point 14. Compatible with pixel formats of the YCbCr family.