Struct WpColorRepresentationSurfaceV1

pub struct WpColorRepresentationSurfaceV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
color representation extension to a surface

A wp_color_representation_surface_v1 allows the client to set the color representation metadata of a surface.

By default, a surface does not have any color representation metadata set. The reconstruction of R, G, B signals on such surfaces is compositor implementation defined. The alpha mode is assumed to be premultiplied_electrical when the alpha mode is unset.

If the wl_surface associated with the wp_color_representation_surface_v1 is destroyed, the wp_color_representation_surface_v1 object becomes inert.

This interface has no events.

Implementations



impl WpColorRepresentationSurfaceV1

pub fn destroy(&self)

destroy the color representation

Destroy the wp_color_representation_surface_v1 object.

Destroying this object unsets all the color representation metadata from the surface. See the wp_color_representation_surface_v1 interface description for how a compositor handles a surface without color representation metadata. Unsetting is double-buffered state, see wl_surface.commit.

pub fn set_alpha_mode(&self, alpha_mode: AlphaMode)

set the surface alpha mode

If this protocol object is inert, the protocol error inert is raised.

Assuming an alpha channel exists, it is always linear. The alpha mode determines whether and how the color channels include pre-multiplied alpha. Using straight alpha might have performance benefits.

Only alpha modes advertised by the compositor are allowed to be used as argument for this request. The “alpha_mode” protocol error is raised otherwise.

Alpha mode is double buffered, see wl_surface.commit.

pub fn set_coefficients_and_range( &self, coefficients: Coefficients, range: Range, )

set the matrix coefficients and range

If this protocol object is inert, the protocol error inert is raised.

Set the matrix coefficients and video range which defines the formula and the related constants used to derive red, green and blue signals. Usually coefficients correspond to MatrixCoefficients code points in H.273.

Only combinations advertised by the compositor are allowed to be used as argument for this request. The “coefficients” protocol error is raised otherwise.

A call to wl_surface.commit verifies that the pixel format and the coefficients-range combination in the committed surface contents are compatible, if contents exist. The “pixel_format” protocol error is raised otherwise.

A pixel format is compatible with the coefficients-range combination if the related equations and conventions as defined in H.273 can produce the color channels (RGB or YCbCr) of the pixel format.

For the definition of the supported combination, see the wp_color_representation_surface_v1::coefficients and wp_color_representation_surface_v1::range enums.

The coefficients-range combination is double-buffered, see wl_surface.commit.

pub fn set_chroma_location(&self, chroma_location: ChromaLocation)

set the chroma location

If this protocol object is inert, the protocol error inert is raised.

Set the chroma location type which defines the position of downsampled chroma samples, corresponding to Chroma420SampleLocType code points in H.273.

An invalid chroma location enum value raises the “chroma_location” protocol error.

A call to wl_surface.commit verifies that the pixel format and chroma location type in the committed surface contents are compatible, if contents exist. The “pixel_format” protocol error is raised otherwise.

For the definition of the supported chroma location types, see the wp_color_representation_surface_v1::chroma_location enum.

The chroma location type is double-buffered, see wl_surface.commit.